@@ -24,6 +24,22 @@ if [ "$1" = "enable_autostart" ] ; then
     sed -i 's/#start on stopped rcS/start on stopped rcS/g' /etc/event.d/sshd
 fi
 
+if [ "$1" = "wlan_started" ] ; then
+    WLAN_IP=$(/sbin/ifconfig wlan0 | sed -n 's/.*inet addr:\([0-9.]\+\).*/\1/p')
+    if [ ! $WLAN_IP ]; then
+        WLAN_IP="None"
+    fi
+    if [ $(netstat -t | grep :ssh.*ESTABLISHED | grep -c $WLAN_IP) -gt 0 ] \
+    && [ $(ps aux | grep -v grep  | grep -c /usr/sbin/osw-power-management) -eq 0 ]; then
+        nohup /usr/sbin/osw-power-management >/dev/null 2>&1 &
+    fi
+fi
+
+if [ "$1" = "wlan_stopped" ] ; then
+    kill $(ps aux | grep /usr/sbin/osw-power-management | grep -v grep | awk '{print $1}')
+    iwconfig wlan0 power on
+fi
+
 if [ "$1" = "wifipmoff_once" ] ; then
     kill $(ps aux | grep /usr/sbin/osw-power-management | grep -v grep | awk '{print $1}')
     sleep 1
